@@ -4,23 +4,17 @@ use 5.008;  # 5.8.x needed for autodie
 use Carp;
 use strict;
 use warnings;
-use Tie::RefHash;   # To cache subroutine refs
-
-use constant PERL510     => ( $] >= 5.010 );
 
 use constant LEXICAL_TAG => q{:lexical};
 use constant VOID_TAG    => q{:void};
-use constant INSIST_TAG  => q{!};
 
 use constant ERROR_NOARGS    => 'Cannot use lexical %s with no arguments';
-use constant ERROR_VOID_LEX  => VOID_TAG.' cannot be used with lexical scope';
+use constant ERROR_VOID_LEX  => VOID_TAG. 'cannot be used with lexical scope';
 use constant ERROR_LEX_FIRST => LEXICAL_TAG.' must be used as first argument';
 use constant ERROR_NO_LEX    => "no %s can only start with ".LEXICAL_TAG;
 use constant ERROR_BADNAME   => "Bad subroutine name for %s: %s";
 use constant ERROR_NOTSUB    => "%s is not a Perl subroutine";
 use constant ERROR_NOT_BUILT => "%s is neither a builtin, nor a Perl subroutine";
-use constant ERROR_NOHINTS   => "No user hints defined for %s";
-
 use constant ERROR_CANT_OVERRIDE => "Cannot make the non-overridable builtin %s fatal";
 
 use constant ERROR_NO_IPC_SYS_SIMPLE => "IPC::System::Simple required for Fatalised/autodying system()";
@@ -31,42 +25,24 @@ use constant ERROR_AUTODIE_CONFLICT => q{"no autodie '%s'" is not allowed while
 
 use constant ERROR_FATAL_CONFLICT => q{"use Fatal '%s'" is not allowed while "no autodie '%s'" is in effect};
 
-
 # Older versions of IPC::System::Simple don't support all the
 # features we need.
 
 use constant MIN_IPC_SYS_SIMPLE_VER => 0.12;
 
 # All the Fatal/autodie modules share the same version number.
-our $VERSION = '1.999_01';
+our $VERSION = "1.99";
 
 our $Debug ||= 0;
 
-# EWOULDBLOCK values for systems that don't supply their own.
-# Even though this is defined with our, that's to help our
-# test code.  Please don't rely upon this variable existing in
-# the future.
-
-our %_EWOULDBLOCK = (
-    MSWin32 => 33,
-);
-
 # We have some tags that can be passed in for use with import.
 # These are all assumed to be CORE::
 
 my %TAGS = (
-    ':io'      => [qw(:dbm :file :filesys :ipc :socket
-                       read seek sysread syswrite sysseek )],
-    ':dbm'     => [qw(dbmopen dbmclose)],
-    ':file'    => [qw(open close flock sysopen fcntl fileno binmode
-                     ioctl truncate)],
-    ':filesys' => [qw(opendir closedir chdir link unlink rename mkdir
-                      symlink rmdir readlink umask)],
-    ':ipc'     => [qw(:msg :semaphore :shm pipe)],
-    ':msg'     => [qw(msgctl msgget msgrcv msgsnd)],
+    ':io'      => [qw(:file :filesys :socket)],
+    ':file'    => [qw(open close sysopen fcntl fileno)],
+    ':filesys' => [qw(opendir)],
     ':threads' => [qw(fork)],
-    ':semaphore'=>[qw(semctl semget semop)],
-    ':shm'     => [qw(shmctl shmget shmread)],
     ':system'  => [qw(system exec)],
 
     # Can we use qw(getpeername getsockname)? What do they do on failure?
@@ -82,18 +58,6 @@ my %TAGS = (
     # system() to be autodying by default.
 
     ':default' => [qw(:io :threads)],
-
-    # Version specific tags.  These allow someone to specify
-    # use autodie qw(:1.994) and know exactly what they'll get.
-
-    ':1.994' => [qw(:default)],
-    ':1.995' => [qw(:default)],
-    ':1.996' => [qw(:default)],
-    ':1.997' => [qw(:default)],
-    ':1.998' => [qw(:default)],
-    ':1.999' => [qw(:default)],
-    ':1.999_01' => [qw(:default)],
-
 );
 
 $TAGS{':all'}  = [ keys %TAGS ];
@@ -112,12 +76,6 @@ my %Use_defined_or;
     CORE::send
     CORE::open
     CORE::fileno
-    CORE::read
-    CORE::readlink
-    CORE::sysread
-    CORE::syswrite
-    CORE::sysseek
-    CORE::umask
 )} = ();
 
 # Cached_fatalised_sub caches the various versions of our
@@ -140,13 +98,6 @@ my %Package_Fatal = ();
 
 my %Original_user_sub = ();
 
-# Is_fatalised_sub simply records a big map of fatalised subroutine
-# refs.  It means we can avoid repeating work, or fatalising something
-# we've already processed.
-
-my  %Is_fatalised_sub = ();
-tie %Is_fatalised_sub, 'Tie::RefHash';
-
 # We use our package in a few hash-keys.  Having it in a scalar is
 # convenient.  The "guard $PACKAGE" string is used as a key when
 # setting up lexical guards.
@@ -159,10 +110,9 @@ my $NO_PACKAGE    = "no $PACKAGE";      # Used to detect 'no autodie'
 # or 'use autodie'.
 
 sub import {
-    my $class        = shift(@_);
-    my $void         = 0;
-    my $lexical      = 0;
-    my $insist_hints = 0;
+    my $class   = shift(@_);
+    my $void    = 0;
+    my $lexical = 0;
 
     my ($pkg, $filename) = caller();
 
@@ -211,10 +161,6 @@ sub import {
             # When we see :void, set the void flag.
             $void = 1;
 
-        } elsif ($func eq INSIST_TAG) {
-
-            $insist_hints = 1;
-
         } elsif (exists $TAGS{$func}) {
 
             # When it's a tag, expand it.
@@ -224,17 +170,6 @@ sub import {
 
             # Otherwise, fatalise it.
 
-            # Check to see if there's an insist flag at the front.
-            # If so, remove it, and insist we have hints for this sub.
-            my $insist_this;
-
-            if ($func =~ s/^!//) {
-                $insist_this = 1;
-            }
-
-            # TODO: Even if we've already fatalised, we should
-            # check we've done it with hints (if $insist_hints).
-
             # If we've already made something fatal this call,
             # then don't do it twice.
 
@@ -264,8 +199,7 @@ sub import {
             # built-ins.
 
             my $sub_ref = $class->_make_fatal(
-                $func, $pkg, $void, $lexical, $filename,
-                ( $insist_this || $insist_hints )
+                $func, $pkg, $void, $lexical, $filename
             );
 
             $done_this{$func}++;
@@ -326,12 +260,12 @@ sub _install_subs {
 
         # Copy symbols across to temp area.
 
-        no strict 'refs';   ## no critic
+        no strict 'refs';
 
         local *__tmp = *{ $full_path };
 
         # Nuke the old glob.
-        { no strict; delete $pkg_sym->{$sub_name}; }    ## no critic
+        { no strict; delete $pkg_sym->{$sub_name}; }
 
         # Copy innocent bystanders back.
 
@@ -344,7 +278,7 @@ sub _install_subs {
 
         if ($sub_ref) {
 
-            no strict;  ## no critic
+            no strict;
             *{ $pkg_sym . $sub_name } = $sub_ref;
         }
     }
@@ -415,9 +349,6 @@ sub unimport {
 
 # TODO - This is rather terribly inefficient right now.
 
-# NB: Perl::Critic's dump-autodie-tag-contents depends upon this
-# continuing to work.
-
 {
     my %tag_cache;
 
@@ -453,8 +384,6 @@ sub unimport {
 }
 
 # This code is from the original Fatal.  It scares me.
-# It is 100% compatible with the 5.10.0 Fatal module, right down
-# to the scary 'XXXX' comment.  ;)
 
 sub fill_protos {
     my $proto = shift;
@@ -472,35 +401,17 @@ sub fill_protos {
     return @out1;
 }
 
-# This is a backwards compatible version of _write_invocation.  It's
-# recommended you don't use it.
+# This generates the code that will become our fatalised subroutine.
 
 sub write_invocation {
-    my ($core, $call, $name, $void, @args) = @_;
-
-    return Fatal->_write_invocation(
-        $core, $call, $name, $void,
-        0,      # Lexical flag
-        undef,  # Sub, unused in legacy mode
-        undef,  # Subref, unused in legacy mode.
-        @args
-    );
-}
-
-# This version of _write_invocation is used internally.  It's not
-# recommended you call it from external code, as the interface WILL
-# change in the future.
-
-sub _write_invocation {
-
-    my ($class, $core, $call, $name, $void, $lexical, $sub, $sref, @argvs) = @_;
+    my ($class, $core, $call, $name, $void, $lexical, $sub, @argvs) = @_;
 
     if (@argvs == 1) {        # No optional arguments
 
         my @argv = @{$argvs[0]};
         shift @argv;
 
-        return $class->_one_invocation($core,$call,$name,$void,$sub,! $lexical, $sref, @argv);
+        return $class->one_invocation($core,$call,$name,$void,$sub,! $lexical,@argv);
 
     } else {
         my $else = "\t";
@@ -512,44 +423,19 @@ sub _write_invocation {
             push @out, "${else}if (\@_ == $n) {\n";
             $else = "\t} els";
 
-        push @out, $class->_one_invocation($core,$call,$name,$void,$sub,! $lexical, $sref, @argv);
+        push @out, $class->one_invocation($core,$call,$name,$void,$sub,! $lexical,@argv);
         }
-        push @out, qq[
+        push @out, q[
             }
-            die "Internal error: $name(\@_): Do not expect to get ", scalar(\@_), " arguments";
+            die "Internal error: $name(\@_): Do not expect to get ", scalar \@_, " arguments";
     ];
 
         return join '', @out;
     }
 }
 
-
-# This is a slim interface to ensure backward compatibility with
-# anyone doing very foolish things with old versions of Fatal.
-
 sub one_invocation {
-    my ($core, $call, $name, $void, @argv) = @_;
-
-    return Fatal->_one_invocation(
-        $core, $call, $name, $void,
-        undef,   # Sub.  Unused in back-compat mode.
-        1,       # Back-compat flag
-        undef,   # Subref, unused in back-compat mode.
-        @argv
-    );
-
-}
-
-# This is the internal interface that generates code.
-# NOTE: This interface WILL change in the future.  Please do not
-# call this subroutine directly.
-
-# TODO: Whatever's calling this code has already looked up hints.  Pass
-# them in, rather than look them up a second time.
-
-sub _one_invocation {
-    my ($class, $core, $call, $name, $void, $sub, $back_compat, $sref, @argv) = @_;
-
+    my ($class, $core, $call, $name, $void, $sub, $back_compat, @argv) = @_;
 
     # If someone is calling us directly (a child class perhaps?) then
     # they could try to mix void without enabling backwards
@@ -569,13 +455,11 @@ sub _one_invocation {
 
     if ($back_compat) {
 
-        # Use Fatal qw(system) will never be supported.  It generated
-        # a compile-time error with legacy Fatal, and there's no reason
-        # to support it when autodie does a better job.
+        # TODO - Use Fatal qw(system) is not yet supported.  It should be!
 
         if ($call eq 'CORE::system') {
             return q{
-                croak("UNIMPLEMENTED: use Fatal qw(system) not supported.");
+                croak("UNIMPLEMENTED: use Fatal qw(system) not yet supported.");
             };
         }
 
@@ -601,33 +485,14 @@ sub _one_invocation {
     # replace whatever it is that we're calling; as such, we actually
     # calling a subroutine ref.
 
-    my $human_sub_name = $core ? $call : $sub;
+    # Unfortunately, none of this tells us the *ultimate* name.
+    # For example, if I export 'copy' from File::Copy, I'd like my
+    # ultimate name to be File::Copy::copy.
+    #
+    # TODO - Is there any way to find the ultimate name of a sub, as
+    # described above?
 
-    # Should we be testing to see if our result is defined, or
-    # just true?
-
-    my $use_defined_or;
-
-    my $hints;      # All user-sub hints, including list hints.
-
-    if ( $core ) {
-
-        # Core hints are built into autodie.
-
-        $use_defined_or = exists ( $Use_defined_or{$call} );
-
-    }
-    else {
-
-        # User sub hints are looked up using autodie::hints,
-        # since users may wish to add their own hints.
-
-        require autodie::hints;
-
-        $hints = autodie::hints->get_hints_for( $sref );
-    }
-
-    # Checks for special core subs.
+    my $true_sub_name = $core ? $call : $sub;
 
     if ($call eq 'CORE::system') {
 
@@ -664,7 +529,7 @@ sub _one_invocation {
 
                 die autodie::exception::system->new(
                     function => q{CORE::system}, args => [ @argv ],
-                    message => "\$E", errno => \$!,
+                    message => "\$E"
                 );
             }
 
@@ -673,141 +538,39 @@ sub _one_invocation {
 
     }
 
+
+    # Should we be testing to see if our result is defined, or
+    # just true?
+    my $use_defined_or = exists ( $Use_defined_or{$call} );
+
     local $" = ', ';
 
     # If we're going to throw an exception, here's the code to use.
     my $die = qq{
         die $class->throw(
-            function => q{$human_sub_name}, args => [ @argv ],
-            pragma => q{$class}, errno => \$!,
+            function => q{$true_sub_name}, args => [ @argv ],
+            pragma => q{$class}
         )
     };
 
-    if ($call eq 'CORE::flock') {
-
-        # flock needs special treatment.  When it fails with
-        # LOCK_UN and EWOULDBLOCK, then it's not really fatal, it just
-        # means we couldn't get the lock right now.
-
-        require POSIX;      # For POSIX::EWOULDBLOCK
-
-        local $@;   # Don't blat anyone else's $@.
-
-        # Ensure that our vendor supports EWOULDBLOCK.  If they
-        # don't (eg, Windows), then we use known values for its
-        # equivalent on other systems.
-
-        my $EWOULDBLOCK = eval { POSIX::EWOULDBLOCK(); }
-                          || $_EWOULDBLOCK{$^O}
-                          || _autocroak("Internal error - can't overload flock - EWOULDBLOCK not defined on this system.");
-
-        require Fcntl;      # For Fcntl::LOCK_NB
-
-        return qq{
-
-            # Try to flock.  If successful, return it immediately.
-
-            my \$retval = $call(@argv);
-            return \$retval if \$retval;
-
-            # If we failed, but we're using LOCK_NB and
-            # returned EWOULDBLOCK, it's not a real error.
-
-            if (\$_[1] & Fcntl::LOCK_NB() and \$! == $EWOULDBLOCK ) {
-                return \$retval;
-            }
-
-            # Otherwise, we failed.  Die noisily.
-
-            $die;
-
-        };
-    }
-
-    # AFAIK everything that can be given an unopned filehandle
-    # will fail if it tries to use it, so we don't really need
-    # the 'unopened' warning class here.  Especially since they
-    # then report the wrong line number.
-
-    my $code = qq[
-        no warnings qw(unopened);
-
+    return qq{
         if (wantarray) {
             my \@results = $call(@argv);
-
-    ];
-
-    if ( $hints and ( ref($hints->{list} ) || "" ) eq 'CODE' ) {
-
-        # NB: Subroutine hints are passed as a full list.
-        # This differs from the 5.10.0 smart-match behaviour,
-        # but means that context unaware subroutines can use
-        # the same hints in both list and scalar context.
-
-        $code .= qq{
-            if ( \$hints->{list}->(\@results) ) { $die };
-        };
-    }
-    elsif ( PERL510 and $hints ) {
-        $code .= qq{
-            if ( \@results ~~ \$hints->{list} ) { $die };
-        };
-    }
-    elsif ( $hints ) {
-        # XXX - Turn into a proper diagnostic.
-        croak "Non-subroutine list hints for $sub are not supported under Perl 5.8.x";
-    }
-    else {
-        $code .= qq{
-            # An empty list, or a single undef is failure
+            # If we got back nothing, or we got back a single
+            # undef, we die.
             if (! \@results or (\@results == 1 and ! defined \$results[0])) {
                 $die;
-            }
-        }
-    }
-
-    # Tidy up the end of our wantarray call.
-
-    $code .= qq[
+            };
             return \@results;
         }
-    ];
 
+        # Otherwise, we're in scalar context.
+        # We're never in a void context, since we have to look
+        # at the result.
 
-    # Otherwise, we're in scalar context.
-    # We're never in a void context, since we have to look
-    # at the result.
-
-    $code .= qq{
         my \$result = $call(@argv);
-    };
 
-    if ( $hints and ( ref($hints->{scalar} ) || "" ) eq 'CODE' ) {
-
-        # We always call code refs directly, since that always
-        # works in 5.8.x, and always works in 5.10.1
-
-        return $code .= qq{
-            if ( \$hints->{scalar}->(\$result) ) { $die };
-            return \$result;
-        };
-
-    }
-    elsif (PERL510 and $hints) {
-        return $code . qq{
-
-            if ( \$result ~~ \$hints->{scalar} ) { $die };
-
-            return \$result;
-        };
-    }
-    elsif ( $hints ) {
-        # XXX - Turn into a proper diagnostic.
-        croak "Non-subroutine list hints for $sub are not supported under Perl 5.8.x";
-    }
-
-    return $code .
-    ( $use_defined_or ? qq{
+    } . ( $use_defined_or ? qq{
 
         $die if not defined \$result;
 
@@ -829,11 +592,9 @@ sub _one_invocation {
 # TODO: Taking a huge list of arguments is awful.  Rewriting to
 #       take a hash would be lovely.
 
-# TODO - BACKCOMPAT - This is not yet compatible with 5.10.0
-
 sub _make_fatal {
-    my($class, $sub, $pkg, $void, $lexical, $filename, $insist) = @_;
-    my($name, $code, $sref, $real_proto, $proto, $core, $call, $hints);
+    my($class, $sub, $pkg, $void, $lexical, $filename) = @_;
+    my($name, $code, $sref, $real_proto, $proto, $core, $call);
     my $ini = $sub;
 
     $sub = "${pkg}::$sub" unless $sub =~ /::/;
@@ -856,15 +617,12 @@ sub _make_fatal {
 
     if (defined(&$sub)) {   # user subroutine
 
-        # NOTE: Previously we would localise $@ at this point, so
-        # the following calls to eval {} wouldn't interfere with anything
-        # that's already in $@.  Unfortunately, it would also stop
-        # any of our croaks from triggering(!), which is even worse.
-
         # This could be something that we've fatalised that
         # was in core.
 
-        if ( $Package_Fatal{$sub} and do { local $@; eval { prototype "CORE::$name" } } ) {
+        local $@; # Don't clobber anyone else's $@
+
+        if ( $Package_Fatal{$sub} and eval { prototype "CORE::$name" } ) {
 
             # Something we previously made Fatal that was core.
             # This is safe to replace with an autodying to core
@@ -882,33 +640,12 @@ sub _make_fatal {
 
         } else {
 
-            # If this is something we've already fatalised or played with,
-            # then look-up the name of the original sub for the rest of
-            # our processing.
-
-            $sub = $Is_fatalised_sub{\&$sub} || $sub;
-
             # A regular user sub, or a user sub wrapping a
             # core sub.
 
             $sref = \&$sub;
             $proto = prototype $sref;
             $call = '&$sref';
-            require autodie::hints;
-
-            $hints = autodie::hints->get_hints_for( $sref );
-
-            # If we've insisted on hints, but don't have them, then
-            # bail out!
-
-            if ($insist and not $hints) {
-                croak(sprintf(ERROR_NOHINTS, $name));
-            }
-
-            # Otherwise, use the default hints if we don't have
-            # any.
-
-            $hints ||= autodie::hints::DEFAULT_HINTS();
 
         }
 
@@ -921,35 +658,24 @@ sub _make_fatal {
         # If we're fatalising system, then we need to load
         # helper code.
 
-        # The business with $E is to avoid clobbering our caller's
-        # $@, and to avoid $@ being localised when we croak.
+        eval {
+            require IPC::System::Simple; # Only load it if we need it.
+            require autodie::exception::system;
+        };
 
-        my $E;
+        if ($@) { croak ERROR_NO_IPC_SYS_SIMPLE; }
 
-        {
-            local $@;
-
-            eval {
-                require IPC::System::Simple; # Only load it if we need it.
-                require autodie::exception::system;
-            };
-            $E = $@;
-        }
-
-        if ($E) { croak ERROR_NO_IPC_SYS_SIMPLE; }
-
-        # Make sure we're using a recent version of ISS that actually
-        # support fatalised system.
-        if ($IPC::System::Simple::VERSION < MIN_IPC_SYS_SIMPLE_VER) {
-            croak sprintf(
-            ERROR_IPC_SYS_SIMPLE_OLD, MIN_IPC_SYS_SIMPLE_VER,
-            $IPC::System::Simple::VERSION
-            );
-        }
+            # Make sure we're using a recent version of ISS that actually
+            # support fatalised system.
+            if ($IPC::System::Simple::VERSION < MIN_IPC_SYS_SIMPLE_VER) {
+                croak sprintf(
+                ERROR_IPC_SYS_SIMPLE_OLD, MIN_IPC_SYS_SIMPLE_VER,
+                $IPC::System::Simple::VERSION
+                );
+            }
 
         $call = 'CORE::system';
         $name = 'system';
-        $core = 1;
 
     } elsif ($name eq 'exec') {
         # Exec doesn't have a prototype.  We don't care.  This
@@ -961,13 +687,8 @@ sub _make_fatal {
         $core = 1;
 
     } else {            # CORE subroutine
-        my $E;
-        {
-            local $@;
-            $proto = eval { prototype "CORE::$name" };
-            $E = $@;
-        }
-        croak(sprintf(ERROR_NOT_BUILT,$name)) if $E;
+        $proto = eval { prototype "CORE::$name" };
+        croak(sprintf(ERROR_NOT_BUILT,$name)) if $@;
         croak(sprintf(ERROR_CANT_OVERRIDE,$name)) if not defined $proto;
         $core = 1;
         $call = "CORE::$name";
@@ -992,7 +713,7 @@ sub _make_fatal {
     # results code that's in the wrong package, and hence has
     # access to the wrong package filehandles.
 
-    if (my $subref = $Cached_fatalised_sub{$class}{$sub}{$void}{$lexical}) {
+    if (my $subref = $Cached_fatalised_sub{$sub}{$void}{$lexical}) {
         $class->_install_subs($pkg, { $name => $subref });
         return $sref;
     }
@@ -1007,7 +728,7 @@ sub _make_fatal {
     $code .= "no warnings qw(exec);\n" if $call eq "CORE::exec";
 
     my @protos = fill_protos($proto);
-    $code .= $class->_write_invocation($core, $call, $name, $void, $lexical, $sub, $sref, @protos);
+    $code .= $class->write_invocation($core, $call, $name, $void, $lexical, $sub, @protos);
     $code .= "}\n";
     warn $code if $Debug;
 
@@ -1021,20 +742,10 @@ sub _make_fatal {
     # and filehandles.
 
     {
-        no strict 'refs'; ## no critic # to avoid: Can't use string (...) as a symbol ref ...
-
-        my $E;
-
-        {
-            local $@;
-            $code = eval("package $pkg; use Carp; $code");  ## no critic
-            $E = $@;
-        }
-
-        if (not $code) {
-            croak("Internal error in autodie/Fatal processing $true_name: $E");
-
-        }
+        local $@;
+        no strict 'refs'; # to avoid: Can't use string (...) as a symbol ref ...
+        $code = eval("package $pkg; use Carp; $code");
+        Carp::confess("$@") if $@;
     }
 
     # Now we need to wrap our fatalised sub inside an itty bitty
@@ -1057,19 +768,9 @@ sub _make_fatal {
 
             sub$real_proto {
 
-                # If we're inside a string eval, we can end up with a
-                # whacky filename.  The following code allows autodie
-                # to propagate correctly into string evals.
-
-                my \$caller_level = 0;
-
-                while ( (caller \$caller_level)[1] =~ m{^\\(eval \\d+\\)\$} ) {
-                    \$caller_level++;
-                }
-
                 # If we're called from the correct file, then use the
                 # autodying code.
-                goto &\$code if ((caller \$caller_level)[1] eq \$filename);
+                goto &\$code if ((caller)[1] eq \$filename);
 
                 # Oh bother, we've leaked into another file.  Call the
                 # original code.  Note that \$sref may actually be a
@@ -1084,7 +785,7 @@ sub _make_fatal {
         # Warning: The following code may disturb some viewers.
 
         # TODO: It should be possible to combine this with
-        # write_invocation().
+        # write invocations.
 
         foreach my $proto (@protos) {
             local $" = ", ";    # So @args is formatted correctly.
@@ -1100,91 +801,26 @@ sub _make_fatal {
 
         # warn "$leak_guard\n";
 
-        my $E;
-        {
-            local $@;
+        local $@;
 
-            $leak_guard = eval $leak_guard;  ## no critic
+        $leak_guard = eval $leak_guard;
 
-            $E = $@;
-        }
-
-        die "Internal error in $class: Leak-guard installation failure: $E" if $E;
+        die "Internal error in $class: Leak-guard installation failure: $@" if $@;
     }
 
-    my $installed_sub = $leak_guard || $code;
+    $class->_install_subs($pkg, { $name => $leak_guard || $code });
 
-    $class->_install_subs($pkg, { $name => $installed_sub });
-
-    $Cached_fatalised_sub{$class}{$sub}{$void}{$lexical} = $installed_sub;
-
-    # Cache that we've now overriddent this sub.  If we get called
-    # again, we may need to find that find subroutine again (eg, for hints).
-
-    $Is_fatalised_sub{$installed_sub} = $sref;
+    $Cached_fatalised_sub{$sub}{$void}{$lexical} = $leak_guard || $code;
 
     return $sref;
 
 }
 
-# This subroutine exists primarily so that child classes can override
-# it to point to their own exception class.  Doing this is significantly
-# less complex than overriding throw()
+sub throw {
+    my ($class, @args) = @_;
 
-sub exception_class { return "autodie::exception" };
-
-{
-    my %exception_class_for;
-    my %class_loaded;
-
-    sub throw {
-        my ($class, @args) = @_;
-
-        # Find our exception class if we need it.
-        my $exception_class =
-             $exception_class_for{$class} ||= $class->exception_class;
-
-        if (not $class_loaded{$exception_class}) {
-            if ($exception_class =~ /[^\w:']/) {
-                confess "Bad exception class '$exception_class'.\nThe '$class->exception_class' method wants to use $exception_class\nfor exceptions, but it contains characters which are not word-characters or colons.";
-            }
-
-            # Alas, Perl does turn barewords into modules unless they're
-            # actually barewords.  As such, we're left doing a string eval
-            # to make sure we load our file correctly.
-
-            my $E;
-
-            {
-                local $@;   # We can't clobber $@, it's wrong!
-                eval "require $exception_class"; ## no critic
-                $E = $@;    # Save $E despite ending our local.
-            }
-
-            # We need quotes around $@ to make sure it's stringified
-            # while still in scope.  Without them, we run the risk of
-            # $@ having been cleared by us exiting the local() block.
-
-            confess "Failed to load '$exception_class'.\nThis may be a typo in the '$class->exception_class' method,\nor the '$exception_class' module may not exist.\n\n $E" if $E;
-
-            $class_loaded{$exception_class}++;
-
-        }
-
-        return $exception_class->new(@args);
-    }
-}
-
-# For some reason, dying while replacing our subs doesn't
-# kill our calling program.  It simply stops the loading of
-# autodie and keeps going with everything else.  The _autocroak
-# sub allows us to die with a vegence.  It should *only* ever be
-# used for serious internal errors, since the results of it can't
-# be captured.
-
-sub _autocroak {
-    warn Carp::longmess(@_);
-    exit(255);  # Ugh!
+    require autodie::exception;
+    return autodie::exception->new(@args);
 }
 
 package autodie::Scope::Guard;
@@ -1311,10 +947,6 @@ C<Fatal> clobbers the context in which a function is called and always
 makes it a scalar context, except when the C<:void> tag is used.
 This problem does not exist in L<autodie>.
 
-"Used only once" warnings can be generated when C<autodie> or C<Fatal>
-is used with package filehandles (eg, C<FILE>).  It's strongly recommended
-you use scalar filehandles instead.
-
 =head1 AUTHOR
 
 Original module by Lionel Cons (CERN).
