@@ -8,7 +8,7 @@ our @ISA = qw(Fatal);
 our $VERSION;
 
 BEGIN {
-    $VERSION = '1.999_01';
+    $VERSION = "1.99";
 }
 
 use constant ERROR_WRONG_FATAL => q{
@@ -73,13 +73,11 @@ autodie - Replace functions with ones that succeed or die with lexical scope
 
 =head1 SYNOPSIS
 
-    use autodie;            # Recommended: implies 'use autodie qw(:default)'
-
-    use autodie qw(:all);   # Recommended more: defaults and system/exec.
+    use autodie;    # Recommended, implies 'use autodie qw(:default)'
 
     use autodie qw(open close);   # open/close succeed or die
 
-    open(my $fh, "<", $filename); # No need to check!
+    open(my $fh, "<", $filename); # No need to check! 
 
     {
         no autodie qw(open);          # open failures won't die
@@ -174,50 +172,14 @@ The categories are currently:
     :all
         :default
             :io
-                read
-                seek
-                sysread
-                sysseek
-                syswrite
-                :dbm
-                    dbmclose
-                    dbmopen
                 :file
-                    binmode
                     close
                     fcntl
                     fileno
-                    flock
-                    ioctl
                     open
                     sysopen
-                    truncate
                 :filesys
-                    chdir
-                    closedir
                     opendir
-                    link
-                    mkdir
-                    readlink
-                    rename
-                    rmdir
-                    symlink
-                    unlink
-                :ipc
-                    pipe
-                    :msg
-                        msgctl
-                        msgget
-                        msgrcv
-                        msgsnd
-                    :semaphore
-                        semctl
-                        semget
-                        semop
-                    :shm
-                        shmctl
-                        shmget
-                        shmread
                 :socket
                     accept
                     bind
@@ -236,85 +198,14 @@ The categories are currently:
             exec
 
 
-Note that while the above category system is presently a strict
-hierarchy, this should not be assumed.
-
 A plain C<use autodie> implies C<use autodie qw(:default)>.  Note that
 C<system> and C<exec> are not enabled by default.  C<system> requires
 the optional L<IPC::System::Simple> module to be installed, and enabling
 C<system> or C<exec> will invalidate their exotic forms.  See L</BUGS>
 below for more details.
 
-The syntax:
-
-    use autodie qw(:1.994);
-
-allows the C<:default> list from a particular version to be used.  This
-provides the convenience of using the default methods, but the surity
-that no behavorial changes will occur if the C<autodie> module is
-upgraded.
-
-You can enable C<autodie> for all of Perl's built-ins, including
-C<system> and C<exec> with:
-
-    use autodie qw(:all);
-
-=head1 FUNCTION SPECIFIC NOTES
-
-=head2 flock
-
-It is not considered an error for C<flock> to return false if it fails
-to an C<EWOULDBLOCK> (or equivalent) condition.  This means one can
-still use the common convention of testing the return value of
-C<flock> when called with the C<LOCK_NB> option:
-
-    use autodie;
-
-    if ( flock($fh, LOCK_EX | LOCK_NB) ) {
-        # We have a lock
-    }
-
-Autodying C<flock> will generate an exception if C<flock> returns
-false with any other error.
-
-=head2 system/exec
-
-The C<system> built-in is considered to have failed in the following
-circumstances:
-
-=over 4
-
-=item *
-
-The command does not start.
-
-=item *
-
-The command is killed by a signal.
-
-=item *
-
-The command returns a non-zero exit value (but see below).
-
-=back
-
-On success, the autodying form of C<system> returns the I<exit value>
-rather than the contents of C<$?>.
-
-Additional allowable exit values can be supplied as an optional first
-argument to autodying C<system>:
-
-    system( [ 0, 1, 2 ], $cmd, @args);  # 0,1,2 are good exit values
-
-C<autodie> uses the L<IPC::System::Simple> module to change C<system>.
-See its documentation for further information.
-
-Applying C<autodie> to C<system> or C<exec> causes the exotic
-forms C<system { $cmd } @args > or C<exec { $cmd } @args>
-to be considered a syntax error until the end of the lexical scope.
-If you really need to use the exotic form, you can call C<CORE::system>
-or C<CORE::exec> instead, or use C<no autodie qw(system exec)> before
-calling the exotic form.
+Note that while the above category system is presently a strict
+hierarchy, this should not be assumed.
 
 =head1 GOTCHAS
 
@@ -334,52 +225,41 @@ end the end of the current block with C<no autodie>.
 To disable autodie for only a single function (eg, open)
 use or C<no autodie qw(open)>.
 
-=item No user hints defined for %s
-
-You've insisted on hints for user-subroutines, either by pre-pending
-a C<!> to the subroutine name itself, or earlier in the list of arguments
-to C<autodie>.  However the subroutine in question does not have
-any hints available.
-
 =back
 
 See also L<Fatal/DIAGNOSTICS>.
 
 =head1 BUGS
 
+Applying C<autodie> to C<system> or C<exec> causes the exotic
+forms C<system { $cmd } @args > or C<exec { $cmd } @args>
+to be considered a syntax error until the end of the lexical scope.
+If you really need to use the exotic form, you can call C<CORE::system>
+or C<CORE::exec> instead, or use C<no autodie qw(system exec)> before
+calling the exotic form.
+
 "Used only once" warnings can be generated when C<autodie> or C<Fatal>
 is used with package filehandles (eg, C<FILE>).  It's strongly recommended
 you use scalar filehandles instead.
 
-Under Perl 5.8 only, C<autodie> I<does not> propagate into string C<eval>
-statements, although it can be explicitly enabled inside a string
-C<eval>.  This bug does not affect block C<eval> statements in
-any version of Perl.
-
 When using C<autodie> or C<Fatal> with user subroutines, the
 declaration of those subroutines must appear before the first use of
 C<Fatal> or C<autodie>, or have been exported from a module.
 Attempting to ue C<Fatal> or C<autodie> on other user subroutines will
 result in a compile-time error.
 
+A TODO list of items remaining for improvement can be found in
+the development tree for the module at
+L<http://github.com/pfenwick/autodie/tree/master/TODO>.
+
 =head2 REPORTING BUGS
 
 Please report bugs via the CPAN Request Tracker at
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=autodie>.
 
-=head1 FEEDBACK
-
-If you find this module useful, please consider rating it on the
-CPAN Ratings service at
-L<http://cpanratings.perl.org/rate?distribution=autodie> .
-
-The module author loves to hear how C<autodie> has made your life
-better (or worse).  Feedback can be sent to
-E<lt>pjf@perltraining.com.auE<gt>.
-
 =head1 AUTHOR
 
-Copyright 2008-2009, Paul Fenwick E<lt>pjf@perltraining.com.auE<gt>
+Copyright 2008, Paul Fenwick E<lt>pjf@perltraining.com.auE<gt>
 
 =head1 LICENSE
 
@@ -390,9 +270,6 @@ same terms as Perl itself.
 
 L<Fatal>, L<autodie::exception>, L<IPC::System::Simple>
 
-I<Perl tips, autodie> at
-L<http://perltraining.com.au/tips/2008-08-20.html>
-
 =head1 ACKNOWLEDGEMENTS
 
 Mark Reed and Roland Giersig -- Klingon translators.
